Crate statime_base

Crate statime_base 

Base types and traits for time management.

Structs

ActiveLinkData
Information on an active link provided by the controller.
ClockId
Unique identifier for a clock
DirectedLinkId
An identifier for a link with a specific direction.
Duration
A span of time, or a difference of two timestamps.
LinkId
Unique identifier for a link
Measurement
A measurement done on a link.
TAI
Marker for the TAI timescale
TimeSnapshot
Snapshot of the synchronization state of a clock.
Timestamp
A timestamp in the scale Timescale.
UTC
Marker for the UTC timescale

Enums

ClockError
Errors than can occur when interacting with a clock
Direction
Direction of a directed link. This is used to indicate which direction a measurement is being made in.
LeapStatus
Information on what the next leap second is going to be.
SourceType
The type of a used source of time.
UniversalTimestamp
A timestamp that can be in either the UTC or TAI timescales.

Traits

Clock
Interface for a controllable clock This needs to be a trait as a single system can have multiple clocks which need different implementation for steering and/or now.
Controller
A controller for clocks in a system.
Link
A measurement link between clocks.
StdController
Extensions to the controller trait which can only be implemented with the standard library available.