pub enum ClockError {
PermissionDenied,
NoDevice,
NotSupported,
InvalidValue,
Unknown,
}Expand description
Errors than can occur when interacting with a clock
Variants
PermissionDenied
Insufficient permissions to perform the requested operation
NoDevice
The underlying clock device is no longer available
NotSupported
The requested operation is not supported by the clock or OS
InvalidValue
One of the provided values is invalid
Unknown
An unknown error occured when interacting with the clock