pub enum LeapStatus {
None,
Leap59,
Leap61,
}Expand description
Information on what the next leap second is going to be.
Variants
None
There is no leap second at the end of the month.
Leap59
A second needs to be removed from the last minute of the month.
Leap61
A second needs to be inserted into the last minute of the month.