ActiveLinkData

Struct ActiveLinkData 

pub struct ActiveLinkData {
    pub id: LinkId,
    pub importance: f64,
}
Information on an active link provided by the controller.

Fields

id: LinkId

The identifier of the active link.

importance: f64

A number indicating the relative contribution of this link to the phase of the system clock.

The units of this are arbitrary, and no assumptions should be made on the size of these numbers. A link with twice the importance will have roughly twice as much impact on the phase of the system clock.