pub struct DirectedLinkId(/* private fields */);Expand description
An identifier for a link with a specific direction.
Implementations
Sourceimpl DirectedLinkId
impl DirectedLinkId
Sourcepub fn new(link_id: LinkId, direction: Direction) -> DirectedLinkId
pub fn new(link_id: LinkId, direction: Direction) -> DirectedLinkId
Create a new directed link identifier.
Sourcepub fn reverse(self) -> DirectedLinkId
pub fn reverse(self) -> DirectedLinkId
Reverse the directed link to the other way.
Sourcepub fn from_clock(self) -> ClockId
pub fn from_clock(self) -> ClockId
Return the clock that is the source of the directed link.
Sourcepub fn to_clock(self) -> ClockId
pub fn to_clock(self) -> ClockId
Return the clock that is the destination of the directed link.
Sourcepub fn is_reverse_of(self, other: DirectedLinkId) -> bool
pub fn is_reverse_of(self, other: DirectedLinkId) -> bool
Returns true if the two directed links are the same link but in opposite directions.