pub struct Duration(/* private fields */);Expand description
A span of time, or a difference of two timestamps.
Arithmetic on durations is implemented as saturating.
Implementations
Sourceimpl Duration
impl Duration
Sourcepub fn as_seconds(self) -> f64
pub fn as_seconds(self) -> f64
The length of the duration as a floating point number of seconds.
Note: Very large durations will loose precision when converted to a floating point.
Sourcepub fn as_raw_steps(self) -> i128
pub fn as_raw_steps(self) -> i128
The length of the duration in steps (2^-64ths of a second)
Sourcepub fn from_raw_steps(steps: i128) -> Self
pub fn from_raw_steps(steps: i128) -> Self
Create a duration from a length in steps (2^-64ths of a second)
Sourcepub fn from_f64_seconds(value: f64) -> Self
pub fn from_f64_seconds(value: f64) -> Self
Create a duration from a floating point number of seconds.
Note: If the provided value is too large or too small to representable as a duration, the result will be clamped to the maximum or minimum respectively.
Sourcepub const fn from_seconds_nanos(seconds: i64, nanos: u32) -> Self
pub const fn from_seconds_nanos(seconds: i64, nanos: u32) -> Self
Create a duration from a given number of seconds, plus the given number of nanoseconds.
The nanoseconds are always applied in the positive direction, so for
example from_seconds_nanos(-1, 500_000_000) represents minus half a
second.