pub struct Measurement {
pub send_timestamp: Timestamp<TAI>,
pub recv_timestamp: Timestamp<TAI>,
pub uncertainty: Duration,
}Expand description
A measurement done on a link.
Fields
send_timestamp: Timestamp<TAI>The timestamp at which the synchronization signal was sent.
recv_timestamp: Timestamp<TAI>The timestamp at which the synchronization signal was received.
uncertainty: DurationThe uncertainty of the timestamps.