pub struct LinkId(/* private fields */);Expand description
Unique identifier for a link
This consists of the two clocks that are linked, and a unique identifier for the link itself. A link has no direction in nature, so the order of the clocks does not matter. The third element, the unique identifier, is used to distinguish between multiple links between the same two clocks.
Implementations
Sourceimpl LinkId
impl LinkId
Sourcepub fn first_clock(self) -> ClockId
pub fn first_clock(self) -> ClockId
Get the first clock in the link.
Sourcepub fn second_clock(self) -> ClockId
pub fn second_clock(self) -> ClockId
Get the second clock in the link.
Sourcepub fn contains_clock(self, clock: ClockId) -> bool
pub fn contains_clock(self, clock: ClockId) -> bool
Check if the given clock is part of a link.
Sourcepub fn forward(self) -> DirectedLinkId
pub fn forward(self) -> DirectedLinkId
Get a directed link identifier for the link in the forward direction.
This is the direction from the first to the second clock.
Sourcepub fn reverse(self) -> DirectedLinkId
pub fn reverse(self) -> DirectedLinkId
Get a directed link identifier for the link in the reverse direction.
This is the direction from the second to the first clock.