Timestamp

Struct Timestamp 

pub struct Timestamp<Timescale>(/* private fields */);
A timestamp in the scale Timescale.

Arithmetic on timestamps is implemented as wrapping.

The timescale ensures that arithmetic done with timescales is done with the correct timescale on both sides. This ensures that for example the following doesn’t compile:

ⓘ
let delta = Timestamp::<UTC>::from_seconds_nanos_since_unix_epoch(100, 0) - Timestamp::<TAI>::from_seconds_nanos_since_unix_epoch(50, 0);

Implementations

Source

impl<A> Timestamp<A>

pub const UNIX_EPOCH: Timestamp<A>

Representation of the UNIX EPOCH in this timescale.

In other words: midnight on the first of januari 1970, as defined in the given timescale.

pub fn from_seconds_nanos_since_unix_epoch( seconds: u64, nanos: u32, ) -> Timestamp<A>

Create a new timestamp on the timescale, the given number of seconds and nanoseconds since the unix epoch.